SmartPlayerKitPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • SmartPlayerKitPlatform
Implementers

Constructors

SmartPlayerKitPlatform()
Constructs a SmartPlayerKitPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SmartPlayerKitPlatform
The default instance of SmartPlayerKitPlatform to use.
getter/setter pair